@@ -50,6 +50,8 @@ from csv2oerp import unicode_csv
 from csv2oerp import tools
 from datetime import datetime
 import re
+import os
+import base64
 from csv2oerp.constants_and_vars import STATS
 
 
@@ -211,8 +213,8 @@ def get_ids(model, fields, op=u'&'):
             res = session.server.search(model, search)
         except RuntimeError:
             return _get_ids(b_model, b_field, b_value, b_line)
-        if not res:
-            session._logger.error(u"<%20s> '%s' not found in fields %s" %
+        if not res and b_value not in (False, '', None):
+            session._logger.error(u"<%-20s> '%s' not found in fields %s" %
                                   (model, b_value, fields), extra=STATS[session.id])
         return res
 
@@ -316,7 +318,7 @@ def get_fields(model, fields, op=u'&'):
     return _get_fields
 
 
-def to_boolean(true=u'1', false=u'0', none=u''):
+def to_boolean(true=u'1', false=u'0', none=''):
     u"""Return a boolean depending from the input value.
 
     >>> 'field': Column(2, to_boolean('Y', 'N', ''))
@@ -330,13 +332,16 @@ def to_boolean(true=u'1', false=u'0', none=u''):
     :returns: callback_model
 
     """
+
     def _to_boolean(session, model, field, value, line):
+        res = None
         if value == str(true):
-            return True
+            res = True
         elif value == str(false):
-            return False
+            res = False
         elif value == str(none):
-            return None
+            res = None
+        return res
 
     return _to_boolean
 
@@ -593,3 +598,53 @@ def get_phones(type, prefix=u'+33'):
         return result
 
     return _get_phones
+
+
+def to_binary(*args, **kwargs):
+    u"""Return a binary.
+
+    .. note::
+
+        This function is a rewriting of base64, same signature
+
+    >>> 'file_content': Column(3, to_binary())
+
+    :returns: callback_model
+
+    """
+    def _to_binary(session, model, field, value, line):
+        res = None
+        fname = os.path.join(os.getcwd(), value)
+        if os.path.isfile(fname):
+            with open(fname) as filename:
+                res = base64.b64encode(filename.read(), *args, **kwargs)
+        else:
+            res = base64.b64encode(value, *args, **kwargs)
+        return res
+
+    return _to_binary
+
+
+def from_binary(*args, **kwargs):
+    u"""Return a string.
+
+    .. note::
+
+        This function is a rewriting of base64, same signature
+
+    >>> 'file_content': Column(3, from_binary())
+
+    :returns: callback_model
+
+    """
+    def _from_binary(session, model, field, value, line):
+        res = None
+        fname = os.path.join(os.getcwd(), value)
+        if os.path.isfile(fname):
+            with open(fname) as filename:
+                res = base64.b64encode(filename.read(), *args, **kwargs)
+        else:
+            res = base64.b64decode(value, *args, **kwargs)
+        return res
+
+    return _from_binary
