@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf8 -*-
 ##############################################################################
 #
@@ -39,43 +38,20 @@ EXIT_WARNING = 1
 EXIT_ERROR = 2
 EXIT_UNKNOWN = 3
 LOGGER = None
-STATS = { 'objects': { } }
-FORMAT='%(asctime)-15s %(name)s row[%(line_num)4s] col[%(col_num)2s] %(levelname)-8s %(message)s'
+STATS = {
+    u'duration': 0,
+    u'objects': {}
+    }
+FORMAT=u'%(asctime)-15s %(name)s row[%(line_num)4s] col[%(col_num)2s] %(levelname)-8s %(message)s'
 
 ACTION_PATTERN = {
-    'skip': 'SKIP',
-    'replace': 'REPLACE',
-    'ignore': 'IGNORE',
-    'noupdate': 'NO_UPDATE',
-    'nocreate': 'NO_CREATE',
-    'unique': 'UNIQUE',
-    'required': 'REQUIRED',
-    'router': 'ROUTER',
+    u'skip': u'SKIP',
+    u'replace': u'REPLACE',
+    u'ignore': u'IGNORE',
+    u'noupdate': u'NO_UPDATE',
+    u'nocreate': u'NO_CREATE',
+    u'unique': u'UNIQUE',
+    u'required': u'REQUIRED',
+    u'router': u'ROUTER',
     }
 
-NOISE = {
-        u'e': (u'é', u'è', u'ê', u'ë', ),
-        u'a': (      u'à', u'â', u'ä', ),
-        u'i': (            u'î', u'ï', ),
-        u'u': (      u'ù', u'û', u'ü', ),
-        u'o': (            u'ô', u'ö', ),
-        u'':  (
-            #u'--', u'_',
-            #u'{', u'}', u'[', u']', u'(', u')',
-            #u'?', u'!',
-            #u'#',
-            #u';', u'.', u',', u':',
-            #u'-', u'+', u'=', u'%', '*',
-            #u'\'s', u'\'r', u'\'n', u'\'r\'n', u'\'t',
-            ),
-        u'et': (u'&'),
-        }
-
-OERP = None
-HOST = 'localhost'
-PORT = 8069
-USER = 'admin'
-UID = None
-PWD = 'admin'
-DB = None
-
