@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf8 -*-
 ##############################################################################
 #
@@ -30,40 +29,82 @@
 # 
 ##############################################################################
 
-"""
+u"""
 Exceptions used in csv2oerp.
 
 """
 
-from constants_and_vars import STATS
+from pprint import pformat
 
-class RequiredFieldError(BaseException):
-    """Exception used when a column index has not be found 
+class BadFieldType(BaseException):
+    u"""Exception used when a field is a relation and not relationnal in Oerp
     
     """
-    def __init__(self, model, field, value=None, line=None, logger=None):
+    def __init__(self, model, field, type_):
+        u"""
+        :param model: Object model
+        :type model: str
+        :param field: Field required
+        :type field: str
+        :param type_: Field type 
+        :type type_: str
+
         """
+        msg = u"Model(%s) field(%s) is not a relationnal field.Skipping." % (model, field, type_)
+        super(BadFieldType, self).__init__(msg)
+
+
+class RequiredFieldError(BaseException):
+    u"""Exception used when a column index has not be found 
+    
+    """
+    def __init__(self, model, field):
+        u"""
         :param model: Object model
         :type model: str
         :param field: Field required
         :type field: str
 
         """
-        if line is None:
-            msg = "Required field '%s' has null value ('%s') at line %s. Skipping."\
-                    % (model, field, value, line)
-        else:
-            msg = field
-        #if logger:
-        #    logger.info("<%-20s> %s" % (model, msg), extra=STATS)
+        msg = u"Required model(%s) field(%s) has null value. Skipping." % (model, field)
         super(RequiredFieldError, self).__init__(msg)
 
 
-class ColumnIndexError(IndexError):
-    """Exception used when a column index has not be found 
+class FieldDefinitionError(BaseException):
+    """Exception used when a model is not conform
     
     """
-    def __init__(self, model, field=None, value=None, column=None, logger=None):
+    def __init__(self, msg=u""):
+        """
+        :param model: Object model
+        :type model: str
+        :param msg: Message to be printed
+        :type msg: str
+
+        """
+        super(FieldDefinitionError, self).__init__(msg)
+
+
+class ModelDefinitionError(BaseException):
+    """Exception used when a model is not conform
+    
+    """
+    def __init__(self, msg=u""):
+        """
+        :param model: Object model
+        :type model: str
+        :param msg: Message to be printed
+        :type msg: str
+
+        """
+        super(ModelDefinitionError, self).__init__(msg)
+
+
+class ColumnIndexError(IndexError):
+    """Exception used when a column index has not be found 
+    
+    """
+    def __init__(self, msg=u""):
         """
         :param model: Object model
         :type model: str
@@ -71,13 +112,6 @@ class ColumnIndexError(IndexError):
         :type msg: str
 
         """
-        if column is None:
-            msg = "Invalid column index found for field '%s'('%s') at column %s"\
-                    % (model, field, value, column)
-        else:
-            msg = field
-        #if logger:
-        #    logger.info("<%-20s> %s" % (model, msg), extra=STATS)
         super(ColumnIndexError, self).__init__(msg)
 
 
@@ -85,9 +119,8 @@ class SkipLineException(BaseException):
     """Exception used when a subfunction need to skip a entire particular line
     
     Usefull into lambda statement with field definition
-
     """
-    def __init__(self, model, field=None, value=None, line=None, logger=None):
+    def __init__(self, msg=u""):
         """
         :param model: Object model
         :type model: str
@@ -95,13 +128,6 @@ class SkipLineException(BaseException):
         :type msg: str
 
         """
-        if line is None:
-           msg = "Skipped line for field '%s'('%s') at line %s"\
-                % (field, value, line)
-        else:
-            msg = field
-        #if logger:
-        #    logger.info("<%-20s> %s" % (model, msg), extra=STATS)
         super(SkipLineException, self).__init__(msg)
 
 
@@ -111,7 +137,7 @@ class SkipObjectException(BaseException):
     Usefull into lambda statement with field definition
 
     """
-    def __init__(self, model, field=None, value=None, line=None, logger=None):
+    def __init__(self, msg=u""):
         """
         :param model: Object model
         :type model: str
@@ -119,15 +145,30 @@ class SkipObjectException(BaseException):
         :type msg: str
 
         """
-        global STATS
-        if line is None:
-            msg = "Skipped object for field '%s'('%s') at line %s"\
-                    % (field, value, line)
-        else:
-            msg = field
-        if logger:
-            if 'line_num' not in STATS:
-                STATS['line_num'] = -2 
-            logger.info("<%-20s> %s skipped" % (model, msg), extra=STATS)
         super(SkipObjectException, self).__init__(msg)
 
+class FatalException(BaseException):
+    """Exception used when a fatal error occurs 
+    
+    """
+    def __init__(self, error, line, model, state, search, data, content):
+        """
+        :param model: Object model
+        :type model: str
+        :param msg: Message to be printed
+        :type msg: str
+
+        """
+        msg = u"""
+
+FATAL ERROR line n° %s (%s)
+--------------------------------------------------------------------------------
+  line: %s 
+ model: %s
+ state: %s
+search: %s
+  data:
+%s
+            """ % (line, error, pformat(content), model, state, search, pformat(data))
+        super(FatalException, self).__init__(msg)
+
