@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf8 -*-
 ################################################################################
 #
@@ -30,57 +29,80 @@
 # 
 ################################################################################
 
-"""
+u"""
 Functions tools module.
 
 """
 import os
 import sys
-import unicode_csv
-from constants_and_vars import NOISE
+import unicodedata
 
-def strip_accent(string):
-    """ Replace accents from string with non accented char
+from csv2oerp import unicode_csv
+from csv2oerp.constants_and_vars import STATS
+
+def purge_stats():
+    u"""Re-initialize objects activities resume
 
     """
-    for char, accent_list in NOISE.iteritems():
-        for accent in accent_list:
-            string.replace(accent, char)
-    return string
+    global STATS
+    STATS = {
+        u'objects':{} 
+        }
 
-def clean_line(line, encode_from='utf-8'):
-    """ Encode a list in ``encode_from`` encoding
+def show_stats():
+    u"""Show objectu's model activities resume.
+    At the end of an import for example.
+
+    """
+    sys.stdout.write(u'\n')
+    sys.stdout.write(u'*'*79 + u'\n')
+    sys.stdout.write(u'* Objects activities :' + u' '*32 + u'Written Created Skipped *\n')
+    sys.stdout.write(u'*'*79 + u'\n')
+    for model_name in STATS[u'objects'].keys():
+        sys.stdout.write(u'%(name)-51s : %(written)7s %(created)7s %(skipped)7s' %
+                STATS[u'objects'][model_name])
+        sys.stdout.write(u'\n')
+    sys.stdout.write(u'\n')
+
+def strip_accents(string, normalize=u'NFD', category=u'Mn'):
+    u""" Replace accents from string with non accented char
+
+    """
+    res = (c for c in unicodedata.normalize(normalize, string)
+            if unicodedata.category(c) != category)
+    return u''.join(res)
+
+def clean_line(line, encode_from=u'utf-8'):
+    u""" Encode a list in ``encode_from`` encoding
 
     """
     return [clean(col, encode_from) for col in line]
 
-def clean_lines(lines, encode_from='utf-8'):
-    """ Encode a list of list in ``encode_from`` encoding
+def clean_lines(lines, encode_from=u'utf-8'):
+    u""" Encode a list of list in ``encode_from`` encoding
 
     """
     return [clean_line(line, encode_from) for line in lines]
 
-def clean(string, encode_from='cp1252'):
-    """ Clean a string by removing returns and double quotes.
+def clean(string, encode_from=u'cp1252'):
+    u""" Clean a string by removing returns and double quotes.
 
     """
     try:
         string = unicode(string)
     except:
         pass
-    string.replace('\n', ' ').replace('"', '\'')
+    string.replace(u'\n', u' ').replace(u'"', u'\'')
     try:
-        string = (string[-1] in [val for val in NOISE['']]) and string[:-1] or string
+        string = strip_accents(string)
     except IndexError:
         pass
 
     return string 
 
-def generate_code(filenames=(), header=True, mode='stdout',  delimiter=',',
-        quotechar='"', encoding='utf-8'):
-    """Return a template's skeleton code
-
-    .. versionadded: 0.5.2
+def generate_code(filenames=(), header=True, mode=u'stdout',  delimiter=u',',
+        quotechar=u'"', encoding=u'utf-8'):
+    u"""Return a template's skeleton code
 
     prerequisites: 
         
@@ -95,16 +117,17 @@ def generate_code(filenames=(), header=True, mode='stdout',  delimiter=',',
     :type stdout: str
     
     """
-    if mode != 'stdout':
-        if os.path.isfile(mode):
-            print('A file called `%s` already existed. Overwrites ?' % mode)
-
-        f = open(mode, 'wb')
+    if mode != u'stdout':
+        if os.path.isfile(mode) \
+                and raw_input(u'`%s` already existed. Overwrites ?' % mode) in (u'y', u'Y', u'o', u'O'):
+            f = open(mode, u'wb')
+        else:
+            exit()
     else:
         f = sys.stdout
 
     # HEADERS + SOME CALLBACKS
-    f.write("""#!/usr/bin/env python
+    f.write(u"""#!/usr/bin/env python
 # -*- coding: utf8 -*-
 ################################################################################
 #
@@ -136,28 +159,29 @@ def generate_code(filenames=(), header=True, mode='stdout',  delimiter=',',
 # 
 ################################################################################
 import csv2oerp
-from csv2oerp import get_ids, get_id, to_boolean, to_date
+from csv2oerp import Field, Model, Session, Openerp
+from csv2oerp import callbacks as cb
 
 # OpenERP configuration
-host = 'XXX.XXX.XXX.XXX'
+host = u'localhost'
 port = 8069
-dbname = 'database'
-user = 'admin'
-pwd = 'admin'
-csv2oerp.connect(host, port, user, pwd, dbname)
+dbname = u'database'
+user = u'admin'
+pwd = u'admin'
+lang = u'fr_FR'
+oerp = Openerp(host, port, user, pwd, dbname, lang)
 
 """)
     for filename in filenames:
         # Get file name without extention, replace space by underscore
-        var = unicode(os.path.splitext(filename)[0].replace(' ', '_'))
-        with open(filename, 'r') as f_csv:
-            lines = list(unicode_csv.Reader(f_csv, delimiter=delimiter, quotechar=quotechar, encoding=encoding))
+        var = unicode(os.path.splitext(filename)[0].replace(u' ', u'_').replace(u'.', u'_'))
+        lines = list(unicode_csv.Reader(filename, delimiter=delimiter, quotechar=quotechar, encoding=encoding))
         #===================================================================
         # Header
         #===================================================================
         f.write(u"#" + u"="*79 + "\n")
         f.write(u"# %s\n" % var)
-        f.write(u"#" + u"="*79 + "\n")
+        f.write(u"#" + u"="*79 + u"\n")
         #===================================================================
         # Mapping
         #===================================================================
@@ -168,26 +192,24 @@ csv2oerp.connect(host, port, user, pwd, dbname)
         #===================================================================
         # Functionnal mapping
         #===================================================================
-        f.write(u"%s = csv2oerp.Import()\n" % var)
-        f.write(u"%s.set_filename_to_import(\n    '%s', '%s', '%s', '%s')\n" %\
-                (var, filename, delimiter, quotechar, encoding))
-        f.write(u"%s.set_mapping({\n" % var)
-        f.write(u"    'model name': [\n")
-        f.write(u"        {\n")
+        f.write(u"""%s = Session(u'%s', u'%s',
+    delimiter=u'%s', quotechar=u'%s', encoding=u'%s')\n""" %\
+            (var, var, filename, delimiter, quotechar, encoding))
+        f.write(u"model_name = Model(u'model.name', fields=[\n\n")
         i = 0
         for item in lines[0]:
-            f.write(u"            '%s': (%s, None, False),\n" % (item, i))
+            f.write(u"    Field(name=u'%s', columns=[%s], callbacks=[]),\n" % (i, item))
             i += 1
-        f.write(u"        },\n")
-        f.write(u"    ],\n")
-        f.write(u"})\n")
+        f.write(u'\n')
+        f.write(u"    ], update=True, create=True, search=[])\n")
         f.write(u"\n")
 
     for filename in filenames:
         #===================================================================
         # Start lines
         #===================================================================
-        var = unicode(os.path.splitext(filename)[0].replace(' ', '_'))
+        var = unicode(os.path.splitext(filename)[0].replace(u' ', u'_'))
+        f.write(u"%s.join(oerp, [, ])\n" % var)
         f.write(u"%s.start()\n" % var)
 
     #=======================================================================
@@ -196,7 +218,8 @@ csv2oerp.connect(host, port, user, pwd, dbname)
     f.write(u"\n")
     f.write(u"# Show statistics\n")
     f.write(u"csv2oerp.show_stats()\n")
-    if mode != 'stdout':
+    if mode != u'stdout':
         f.close()
+    print(u'Finished.')
     return
 
