@@ -77,7 +77,10 @@ class Reader:
             raise StopIteration
         row = self.reader[self.offset]
         self.offset += 1
-        return [unicode(_is_null(elmt), self.encoding) for elmt in row]
+        line = [unicode(_is_null(elmt), self.encoding) for elmt in row]
+        if not line:
+            return self.next()
+        return line
 
     def __iter__(self):
         return self
@@ -106,11 +109,15 @@ class Writer:
         self.encoding = encoding
 
     def writerow(self, row):
-        self.writer.writerow([_is_null(elmt).encode(u"utf-8") for elmt in row])
+        line = [_is_null(elmt).encode(u"utf-8") for elmt in row]
+        if not line:
+            return False
+        return self.writer.writerow(line)
 
     def writerows(self, rows):
         for row in rows:
             self.writerow(row)
+        return True
 
     def __del__(self):
         self.csvfile.close()
